@@ -19,7 +19,7 @@
 
 from . import *
 from .__version__ import __version__
-from ._base_client import ApiKeyFrom, FromConvertDot, UrHellFrom
+from ._base_client import ApiKeyFrom, FromConvertDot, RyzenthTools, UrHellFrom
 from ._client import RyzenthApiClient
 from ._new_client import RyzenthAuthClient
 
@@ -28,5 +28,6 @@ __all__ = [
   "RyzenthApiClient",
   "RyzenthAuthClient",
   "UrHellFrom",
-  "FromConvertDot"
+  "FromConvertDot",
+  "RyzenthTools"
 ]
